@@ -5,7 +5,7 @@ import (
 	"io"
 	"os"
 
-	"go.cypherpunks.su/recfile/v2"
+	"go.cypherpunks.su/recfile/v3"
 )
 
 func main() {
@@ -24,7 +24,7 @@ func main() {
 		}
 		fmt.Println("Record:", n)
 		for _, field := range fields {
-			fmt.Printf("%s: %s\n", field.Name, field.Value)
+			fmt.Printf("%s: %s\n", field.F, field.V)
 		}
 		n++
 	}
